/***************************************************************************
                          job_deletetrackphysically.h  -  description
                             -------------------
    begin                : Tue Jun 12 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_DELETETRACKPHYSICALLY_H
#define JOB_DELETETRACKPHYSICALLY_H

#include "prokyon.h"

#include "jobbase.h"

class Job_DeleteTrackPhysically : public JobBase  {
public:
    Job_DeleteTrackPhysically(TRACK *_track);

    int type() {
        return JOB_DELETE_TRACK_PHYSICALLY;
    }

    void run();

    ~Job_DeleteTrackPhysically();

private:
    TRACK *track;
};

#endif
